#!/bin/bash
ACTION=$1
FILE=$2
S3_ENV="RC"

case ${ACTION} in
    upload|download) echo "${ACTION} file" ;;
    *) echo "Invalid action, could be only upload or download" ; exit 1 ;;
esac
if [ "$#" -ne 2 ]
then
  echo "Incorrect number of arguments"
  exit 1
fi

tcr_cli=$(which tcr_cli)
if [ $? -ne 0 ]; then
    echo "tcr_cli doesn't present, exiting"
    exit 1
fi

s3cmd=$(which s3cmd)
if [ $? -ne 0 ]; then
    echo "s3cmd doesn't present, attempting to download"
    pip3 install s3cmd
fi

AWS_KEY=$(tcr_cli show s3.access_id | awk -F' = ' '{print $2}' | sed "s/[\";]//g")
AWS_SECRET=$(tcr_cli show s3.access_secret | awk -F' = ' '{print $2}' | sed "s/[\";]//g")
S3_BUCKET="s3://ter-debug/$S3_ENV"


function s3Download
{
  s3cmd --access_key=${AWS_KEY} --secret_key=${AWS_SECRET} --skip-existing get ${S3_BUCKET}/${FILE} /tmp/
  [ $? -eq 0 ] || echo "Using $S3_BUCKET, is this right? if not, see configurations"
}

function yumInstall
{
  yum install -y -q /tmp/${FILE}
}


# set the path based on the first argument
case "$ACTION" in
  "upload")
  s3Upload
  ;;

  "download")
  s3Download
  ;;

  "install")
  s3Download
  yumInstall
  ;;
esac
